@@ -1,17 +1,21 @@
 # -*- coding: utf-8 -*-
 """
-    zeronimo.helpers
-    ~~~~~~~~~~~~~~~~
+   zeronimo.helpers
+   ~~~~~~~~~~~~~~~~
 
-    Helper functions.
+   Helper functions.
+
+   :copyright: (c) 2013-2016 by Heungsub Lee
+   :license: BSD, see LICENSE for more details.
 
-    :copyright: (c) 2013-2014 by Heungsub Lee
-    :license: BSD, see LICENSE for more details.
 """
+from errno import EINTR
+
 import zmq
 
 
-__all__ = ['class_name', 'make_repr']
+__all__ = ['class_name', 'make_repr', 'socket_type_name',
+           'eintr_retry', 'eintr_retry_zmq', 'Flag']
 
 
 def class_name(obj):
@@ -32,7 +36,7 @@ def _repr_attr(obj, attr, data=None, reprs=None):
 
 def make_repr(obj, params=None, keywords=None, data=None, name=None,
               reprs=None):
-    """Generates a string of object initialization code style. It is useful
+    """Generates a string of object initialization code style.  It is useful
     for custom __repr__ methods::
 
        class Example(object):
@@ -74,4 +78,40 @@ for name in ('PAIR PUB SUB REQ REP DEALER ROUTER PULL PUSH XPUB XSUB '
 
 
 def socket_type_name(socket_type):
+    """Gets the ZeroMQ socket type name."""
     return _socket_type_names[socket_type]
+
+
+def eintr_retry(exc_type, f, *args, **kwargs):
+    """Calls a function.  If an error of the given exception type with
+    interrupted system call (EINTR) occurs calls the function again.
+    """
+    while True:
+        try:
+            return f(*args, **kwargs)
+        except exc_type as exc:
+            if exc.errno != EINTR:
+                raise
+        else:
+            break
+
+
+def eintr_retry_zmq(f, *args, **kwargs):
+    """The specialization of :func:`eintr_retry` by :exc:`zmq.ZMQError`."""
+    return eintr_retry(zmq.ZMQError, f, *args, **kwargs)
+
+
+class Flag(object):
+
+    __slots__ = ('state',)
+
+    def __init__(self, state=False):
+        self(state)
+
+    def __call__(self, state):
+        self.state = state
+
+    def __bool__(self):
+        return bool(self.state)
+
+    __nonzero__ = __bool__
